<?php

namespace Drupal\google_analytics_counter;

use Drupal\Component\Plugin\PluginBase;
use Drupal\node\NodeInterface;

/**
 * Base class for google_analytics_counter_result_processor plugins.
 */
abstract class GoogleAnalyticsCounterResultProcessorPluginBase extends PluginBase implements GoogleAnalyticsCounterResultProcessorInterface {

  /**
   * {@inheritdoc}
   */
  public function label() {
    // Cast the label to a string since it is a TranslatableMarkup object.
    return (string) $this->pluginDefinition['label'];
  }

  public abstract function processPagePathResultRows($feed);

  public function processGacUpdateStorage($nid, $bundle, $vid) {
    // Get all the aliases for a given node id.
    $aliases = [$nid];
    $sum_pageviews = $this->sumPageviews($aliases);
    return $sum_pageviews;
  }

  public function isUpdatePathTable() {
    return TRUE;
  }

  public function isUpdateGacStorage() {
    return TRUE;
  }

  public abstract function gacDisplayCount();


  /**
   * Look up the count via the hash of the paths.
   *
   * @param mixed $aliases
   *   The provided aliases.
   *
   * @return string
   *   Count of views.
   */
  protected function sumPageviews($aliases) {
    // $aliases can make pageview_total greater than pageviews
    // because $aliases can include page aliases, node/id, and node/id/,
    // translations redirects and other URIs which are all the same node.
    $hashes = array_map('md5', $aliases);
    $path_counts = \Drupal::database()->select('google_analytics_counter', 'gac')
      ->fields('gac', ['pageviews'])
      ->condition('pagepath_hash', $hashes, 'IN')
      ->execute();
    $sum_pageviews = 0;
    foreach ($path_counts as $path_count) {
      $sum_pageviews += $path_count->pageviews;
    }

    return $sum_pageviews;
  }

}
